@@ -36,7 +36,7 @@ enum
 {
   GRAPH_COLOR = 1,
   GRAPH_SIZE,
-  GRAPH_HIDE
+  GRAPH_HIDE,
 };
 
 /**
@@ -190,11 +190,7 @@ gtk_databox_graph_class_init (GtkDataboxGraphClass *klass)
   g_type_class_add_private (klass, sizeof (GtkDataboxGraphPrivate));
 }
 
-static void
-gtk_databox_graph_init (GtkDataboxGraph *graph)
-{
-	graph = graph;
-}
+static void gtk_databox_graph_init (GtkDataboxGraph *graph) { graph = graph;}
 
 /**
  * gtk_databox_graph_draw:
