@@ -650,7 +650,7 @@ gtk_databox_ruler_set_orientation (GtkDataboxRuler * ruler,
 
     widget = GTK_WIDGET (ruler);
 
-    /* get the padding */
+    // get the padding
 	GtkRequisition gtkRequisition;
     GtkStyleContext *context= gtk_widget_get_style_context (widget);
     GtkBorder padding;
@@ -768,7 +768,7 @@ gtk_databox_ruler_set_text_orientation (GtkDataboxRuler * ruler,
 
     widget = GTK_WIDGET (ruler);
 
-    /* get the padding */
+    // get the padding
     context= gtk_widget_get_style_context (widget);
     gtk_style_context_get_padding (context, gtk_widget_get_state_flags (widget), &padding);
     gtk_databox_ruler_get_preferred_height (widget, &minimal_height, &natural_height);
@@ -777,12 +777,11 @@ gtk_databox_ruler_set_text_orientation (GtkDataboxRuler * ruler,
         gtkRequisition.width = (padding.left + padding.right) * 2 + RULER_SIZE;
     else
         gtkRequisition.width = ruler->priv->max_y_text_width;
-	gtk_widget_set_size_request(widget, gtkRequisition.width, gtkRequisition.height);
+    gtk_widget_set_size_request(widget, gtkRequisition.width, gtkRequisition.height);
 
-    if (gtk_widget_is_drawable (widget))
-	{
+    if (gtk_widget_is_drawable (widget)) {
         gtk_widget_queue_draw (widget);
-	}
+    }
 }
 
 /**
@@ -1324,8 +1323,8 @@ gtk_databox_ruler_draw_ticks (GtkDataboxRuler * ruler) {
     PangoContext *context;
     PangoLayout *layout;
     PangoRectangle logical_rect, ink_rect;
-	GtkAllocation allocation;
-	GdkRGBA fg_color, bg_color;
+    GtkAllocation allocation;
+    GdkRGBA fg_color, bg_color;
 
     GtkBorder padding;
     gtk_style_context_get_padding (stylecontext, gtk_widget_get_state_flags (widget), &padding);
@@ -1345,8 +1344,8 @@ gtk_databox_ruler_draw_ticks (GtkDataboxRuler * ruler) {
     if (!gtk_widget_is_drawable (GTK_WIDGET (ruler)))
         return;
 
-	gtk_widget_get_allocation(widget, &allocation);
-	stylecontext = gtk_widget_get_style_context(widget);
+    gtk_widget_get_allocation(widget, &allocation);
+    stylecontext = gtk_widget_get_style_context(widget);
 
     layout = gtk_widget_create_pango_layout (widget, "E+-012456789");
 
@@ -1367,7 +1366,8 @@ gtk_databox_ruler_draw_ticks (GtkDataboxRuler * ruler) {
     height = allocation.height;
 
     cr = cairo_create(ruler->priv->backing_surface);
-    gtk_style_context_get_background_color(stylecontext, GTK_STATE_FLAG_NORMAL, &bg_color);
+    //gtk_style_context_get_background_color(stylecontext, GTK_STATE_FLAG_NORMAL, &bg_color);
+    gdk_rgba_parse (&bg_color, "#fefefe");
     gdk_cairo_set_source_rgba (cr, &bg_color);
     cairo_paint(cr);
 
@@ -1589,6 +1589,8 @@ gtk_databox_ruler_draw_pos (GtkDataboxRuler * ruler) {
     gint bs_width, bs_height;
     gint ythickness;
     gdouble increment;
+    GdkDrawingContext *drawc;
+    cairo_region_t *crr;
     cairo_t *cr;
 	GtkAllocation allocation;
 	GdkRGBA fg_color;
@@ -1625,7 +1627,10 @@ gtk_databox_ruler_draw_pos (GtkDataboxRuler * ruler) {
         if (ruler->priv->invert_edge && (bs_width > 0) && (bs_height > 0))
             return; /* return if positive values and inverted */
 
-        cr = gdk_cairo_create (gtk_widget_get_window(widget));
+        crr = gdk_window_get_visible_region (gtk_widget_get_window (widget));
+        drawc = gdk_window_begin_draw_frame (gtk_widget_get_window (widget), crr);
+        cr = gdk_drawing_context_get_cairo_context (drawc);
+        /*cr = gdk_cairo_create (gtk_widget_get_window(widget));*/
 
         /*  If a backing store exists, restore the ruler  */
         if (ruler->priv->backing_surface)
@@ -1663,7 +1668,8 @@ gtk_databox_ruler_draw_pos (GtkDataboxRuler * ruler) {
         }
         cairo_fill (cr);
 
-        cairo_destroy (cr);
+        gdk_window_end_draw_frame (gtk_widget_get_window (widget), drawc);
+        cairo_region_destroy (crr);
 
         /* remember the rectangle of the arrow - so that it may be cleared on re-run */
         ruler->priv->xsrc = x;
@@ -1713,7 +1719,7 @@ gtk_databox_ruler_realize (GtkWidget * widget) {
 
     gtk_style_context_add_class(stylecontext, GTK_STYLE_CLASS_BACKGROUND);
 
-    gtk_style_context_set_background(stylecontext, gtk_widget_get_window(widget));
+    /*gtk_style_context_set_background(stylecontext, gtk_widget_get_window(widget));*/
 
     gtk_databox_ruler_create_backing_surface (ruler);
 }
@@ -1778,13 +1784,15 @@ gtk_databox_ruler_create_backing_surface (GtkDataboxRuler * ruler) {
     GtkWidget *widget;
     gint width;
     gint height;
-	GtkAllocation allocation;
-	cairo_t *cr;
+    GtkAllocation allocation;
+    GdkDrawingContext *drawc;
+    cairo_region_t *crr;
+    cairo_t *cr;
 
     widget = GTK_WIDGET (ruler);
-	gtk_widget_get_allocation(widget, &allocation);
-	width = allocation.width;
-	height = allocation.height;
+    gtk_widget_get_allocation(widget, &allocation);
+    width = allocation.width;
+    height = allocation.height;
 
     if (ruler->priv->backing_surface) {
         if ((width == ruler->priv->old_width) &&
@@ -1797,7 +1805,10 @@ gtk_databox_ruler_create_backing_surface (GtkDataboxRuler * ruler) {
 	ruler->priv->old_width = width;
 	ruler->priv->old_height = height;
 
-	cr = gdk_cairo_create(gtk_widget_get_window(widget));
+    crr = gdk_window_get_visible_region (gtk_widget_get_window (widget));
+    drawc = gdk_window_begin_draw_frame (gtk_widget_get_window (widget), crr);
+    cr = gdk_drawing_context_get_cairo_context (drawc);
+    /*cr = gdk_cairo_create(gtk_widget_get_window(widget));*/
 
     ruler->priv->backing_surface = cairo_surface_create_similar(
 		cairo_get_target(cr),
@@ -1806,6 +1817,9 @@ gtk_databox_ruler_create_backing_surface (GtkDataboxRuler * ruler) {
 
     ruler->priv->xsrc = 0;
     ruler->priv->ysrc = 0;
+
+    gdk_window_end_draw_frame (gtk_widget_get_window (widget), drawc);
+    cairo_region_destroy (crr);
 }
 
 #define __GTK_DATABOX_RULER_C__
