@@ -1,14 +1,15 @@
-/*****************************************************************************/
-/*  Klavaro - a flexible touch typing tutor                                  */
-/*  Copyright (C) 2005, 2006, 2007, 2008 Felipe Castro                       */
-/*  Copyright (C) 2009, 2010, 2011, 2012, 2013 The Free Software Foundation  */
-/*                                                                           */
-/*  This program is free software, licensed under the terms of the GNU       */
-/*  General Public License as published by the Free Software Foundation,     */
-/*  either version 3 of the License, or (at your option) any later version.  */
-/*  You should have received a copy of the GNU General Public License        */
-/*  along with this program.  If not, see <http://www.gnu.org/licenses/>.    */
-/*****************************************************************************/
+/**************************************************************************/
+/*  Klavaro - a flexible touch typing tutor                               */
+/*  Copyright (C) from 2005 until 2008 Felipe Castro                      */
+/*  Copyright (C) from 2009 until 2019 The Free Software Foundation       */
+/*                                                                        */
+/*  This program is free software, licensed under the terms of the GNU    */
+/*  General Public License as published by the Free Software Foundation,  */
+/*  either version 3 of the License, or (at your option) any later        */
+/*  version. You should have received a copy of the GNU General Public    */
+/*  License along with this program. If not,                              */
+/*  see <https://www.gnu.org/licenses/>.                                  */
+/**************************************************************************/
 
 #include <string.h>
 #include <stdio.h>
@@ -38,7 +39,9 @@ gchar *KEYB_EDIT;
 gchar *OTHER_DEFAULT;
 
 static GKeyFile *preferences = NULL;
+static GKeyFile *altcolor = NULL;
 static gboolean curl_ok;
+static gboolean velo_txt;
 static struct
 {
 	gchar *user;
@@ -80,6 +83,12 @@ main_curl_ok ()
 	return (curl_ok);
 }
 
+gboolean
+main_velo_txt ()
+{
+	return (velo_txt);
+}
+
 gboolean
 main_preferences_exist (gchar * group, gchar * key)
 {
@@ -128,14 +137,38 @@ main_preferences_set_boolean (gchar * group, gchar * key, gboolean value)
 	g_key_file_set_boolean (preferences, group, key, value);
 }
 
+gboolean
+main_altcolor_exist (gchar * group, gchar * key)
+{
+	return (g_key_file_has_key (altcolor, group, key, NULL));
+}
+
+gchar *
+main_altcolor_get_string (gchar * group, gchar * key)
+{
+	return (g_key_file_get_string (altcolor, group, key, NULL));
+}
+
+
+gboolean
+main_altcolor_get_boolean (gchar * group, gchar * key)
+{	
+	return (g_key_file_get_boolean (altcolor, group, key, NULL));
+}
+
+void
+main_altcolor_set_boolean (gchar * group, gchar * key, gboolean value)
+{
+	g_key_file_set_boolean (altcolor, group, key, value);
+}
+
 void
 main_preferences_save ()
 {
 	gchar *tmp_name;
 	FILE *fh;
 
-	/*
-	 * Save preferences
+	/* Save preferences
 	 */
 	assert_user_dir ();
 	tmp_name = g_build_filename (main_path_user (), "preferences.ini", NULL);
@@ -150,7 +183,26 @@ main_preferences_save ()
 		if (tmp_name != NULL)
 			fputs (tmp_name, fh);
 		else
-			g_warning ("couldn't save your preferences at the user folder:\n %s", tmp_name);
+			g_warning ("no preferences to be saved!");
+		fclose (fh);
+	}
+	g_free (tmp_name);
+
+	/* Save altcolor
+	 */
+	tmp_name = g_build_filename (main_path_user (), "altcolor.ini", NULL);
+	fh = (FILE *) g_fopen (tmp_name, "w");
+	if (fh == NULL)
+		g_warning ("couldn't save your altcolor file at the user folder:\n %s", tmp_name);
+	else
+	{
+		g_free (tmp_name);
+		tmp_name = NULL;
+		tmp_name = g_key_file_to_data (altcolor, NULL, NULL);
+		if (tmp_name != NULL)
+			fputs (tmp_name, fh);
+		else
+			g_warning ("no altcolors to be saved!");
 		fclose (fh);
 	}
 	g_free (tmp_name);
@@ -194,18 +246,15 @@ main_initialize_global_variables ()
 	 */
 	path.data = g_build_filename ("..", "data", NULL);
 	tmp = g_build_filename (path.data, "basic_lessons.txt", NULL);
-	fh = (FILE *) g_fopen (tmp, "r");
-	if (fh == NULL)
+	if (!g_file_test (tmp, G_FILE_TEST_EXISTS))
 	{
 		g_free (path.data);
 		g_free (tmp);
 		path.data = g_build_filename (PACKAGE_DATA_DIR, PACKAGE, NULL);
 		tmp = g_build_filename (path.data, "basic_lessons.txt", NULL);
-		fh = (FILE *) g_fopen (tmp, "r");
 	}
-	if (fh == NULL)
+	if (! g_file_test (tmp, G_FILE_TEST_EXISTS))
 		g_error ("couldn't find a data file at the data path:\n %s", tmp);
-	fclose (fh);
 	g_free (tmp);
 
 	/* Get a valid scoring path.
@@ -216,18 +265,35 @@ main_initialize_global_variables ()
 		g_mkdir_with_parents (path.score, DIR_PERM);
 	}
 
-	/* Retrieve initial or saved preferences
+	/* Retrieve saved preferences or initial one
 	 */
 	preferences = g_key_file_new ();
 	tmp = g_build_filename (main_path_user (), "preferences.ini", NULL);
 	if (!g_file_test (tmp, G_FILE_TEST_EXISTS))
 	{
 		g_free (tmp);
-		tmp = g_strdup ("/etc/klavaro_preferences.ini");
+		tmp = g_strdup ("/etc/klavaro/preferences.ini");
 	}
 	g_key_file_load_from_file (preferences, tmp, G_KEY_FILE_NONE, NULL);
 	g_free (tmp);
 
+	/* Retrieve saved alternative colors or initial ones
+	 */
+	altcolor = g_key_file_new ();
+	tmp = g_build_filename (main_path_user (), "altcolor.ini", NULL);
+	if (!g_file_test (tmp, G_FILE_TEST_EXISTS))
+	{
+		g_free (tmp);
+		tmp = g_build_filename ("/etc/klavaro/altcolor.ini", NULL);
+	}
+	if (!g_file_test (tmp, G_FILE_TEST_EXISTS))
+	{
+		g_free (tmp);
+		tmp = g_build_filename (main_path_data (), "altcolor.ini", NULL);
+	}
+	g_key_file_load_from_file (altcolor, tmp, G_KEY_FILE_NONE, NULL);
+	g_free (tmp);
+
 	/* Other initializations
 	 */
 	trans_init_lang_name_code ();
@@ -289,8 +355,8 @@ main_gtkbuilder_translation_workaround ()
 static void
 main_window_init ()
 {
-	gchar *tmp;
-	gchar *ttip;
+	gchar *tmp = NULL;
+	gchar *ttip = NULL;
 	PangoAttrList *palist;
 
 	/* Workaround to make GtkBuilder translate all text, on Windows :-(
@@ -314,13 +380,13 @@ main_window_init ()
 		main_preferences_set_boolean ("interface", "speech", TRUE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (get_wg ("checkbutton_speech")),
 		       	main_preferences_get_boolean ("interface", "speech"));
-	tmp = dngettext (PACKAGE, "Dictation mode (depends on this speech synthesizer: %s)",
-		       	"Dictation mode (depends on one of these speech synthesizers: %s)", 1);
+	tmp = g_strdup (dngettext (PACKAGE, "Dictation mode (depends on this speech synthesizer: %s)",
+					    "Dictation mode (depends on one of these speech synthesizers: %s)", 1));
 	ttip = g_strdup_printf (tmp, "Espeak");
+	g_free (tmp);
 	gtk_widget_set_tooltip_text (get_wg ("checkbutton_speech"), ttip);
 	callbacks_shield_set (FALSE);
 	
-
 	/* Set the initial keyboard to use
 	 */
 	keyb_set_combo_kbd ("combobox_kbd_country", "combobox_kbd_variant");
@@ -332,11 +398,11 @@ main_window_init ()
 
 	/* Set pixmaps
 	 */
+	set_pixmap ("image_altcolor", "altcolor.png");
 	set_pixmap ("image_fluid", "fluid.png");
 	set_pixmap ("image_keyboard", "key.png");
-	set_pixmap ("image_beep", "beep.png");
-	set_pixmap ("image_progress", "progress.png");
 	set_pixmap ("image_other", "other.png");
+	set_pixmap ("image_progress", "progress.png");
 	set_pixmap ("image_top10", "top10.png");
 
 	/* Set Top10 TreeViews and Combo
@@ -356,7 +422,6 @@ main_window_init ()
 
 	/* Set main labels (for translation)
 	 */
-	tmp = NULL;
 	tmp = g_strdup_printf ("0 - %s", _("Introduction"));
 	gtk_label_set_text (GTK_LABEL (get_wg ("label_main_intro")), tmp);
 	g_free (tmp);
@@ -366,7 +431,10 @@ main_window_init ()
 	tmp = g_strdup_printf ("2 - %s", _("Adaptability"));
 	gtk_label_set_text (GTK_LABEL (get_wg ("label_main_adapt")), tmp);
 	g_free (tmp);
-	tmp = g_strdup_printf ("3 - %s", _("Speed"));
+	if (velo_txt)
+		tmp = g_strdup_printf ("3 - %s (TXT)", _("Speed"));
+	else
+		tmp = g_strdup_printf ("3 - %s", _("Speed"));
 	gtk_label_set_text (GTK_LABEL (get_wg ("label_main_velo")), tmp);
 	g_free (tmp);
 	tmp = g_strdup_printf ("4 - %s", _("Fluidity"));
@@ -381,6 +449,13 @@ main_window_init ()
 	 */
 	gtk_widget_show (get_wg ("window_main"));
 	window_restore ("main");
+	
+	/* Altcolor toggle button 
+	 */
+	if (!main_altcolor_exist ("colors", "altcolor"))
+		main_altcolor_set_boolean ("colors", "altcolor", FALSE);
+	if (main_altcolor_get_boolean ("colors", "altcolor") == TRUE)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (get_wg ("togglebutton_altcolor")), TRUE);
 
 	/* Run last used module
 	 */
@@ -423,10 +498,11 @@ main (int argc, char *argv[])
 	gboolean show_version = FALSE;
 	GOptionContext *opct;
 	GOptionEntry option[] = {
-		{"version", 'v', 0, G_OPTION_ARG_NONE, &show_version, "Versio", NULL},
+		{"version", 'v', 0, G_OPTION_ARG_NONE, &show_version, "Version", NULL},
+		{"velotxt", 'x', 0, G_OPTION_ARG_NONE, &velo_txt, "Speed TXT", NULL},
 		{NULL}
 	};
-	GError *gerr;
+	GError *gerr = NULL;
 
 	/* Localization
 	 */
@@ -438,16 +514,22 @@ main (int argc, char *argv[])
 
 	/* Command-line arguments
 	 */
-	opct = g_option_context_new ("");
+	opct = g_option_context_new ("\t");
 	g_option_context_set_translation_domain (opct, GETTEXT_PACKAGE);
 	g_option_context_add_main_entries (opct, option, GETTEXT_PACKAGE);
 	g_option_context_add_group (opct, gtk_get_option_group (TRUE));
 	g_setenv ("NO_AT_BRIDGE", "1", FALSE); /* to eliminate annoying accessibility bus warning */
-	g_option_context_parse (opct, &argc, &argv, &gerr);
+	if (g_option_context_parse (opct, &argc, &argv, &gerr) == FALSE)
+	{
+		g_printf ("%s\n", gerr->message);
+		g_printf ("klavaro -h\n");
+		return 0;
+	}
 
 	if (show_version)
 	{
 		g_printf (VERSION"\n");
+		//g_printf (PACKAGE_LOCALE_DIR"\n");
 		return 0;
 	}
 
