@@ -113,6 +113,25 @@ tutor_get_type_name ()
 	return (type_name[tutor.type]);
 }
 
+gboolean 
+tutor_is_tibetan ()
+{
+	gchar *code;
+	gboolean is_tibt;
+
+	if (tutor.type == TT_BASIC || tutor.type == TT_ADAPT)
+	{
+		code = keyb_get_country_code (keyb_get_name ());
+		is_tibt = g_str_equal (code, "bo"); 
+		g_free (code);
+		return (is_tibt);
+	}
+	else
+	{
+		return (g_str_has_prefix (main_preferences_get_string ("interface", "language"), "bo"));
+	}
+}
+
 TutorQuery
 tutor_get_query ()
 {
@@ -473,7 +492,6 @@ tutor_update_intro ()
 
 	/*
 	 * Apply tutor background color and font to the intro 
-	 * FIXME: update deprecated function for background color
 	 */
 	if (main_preferences_exist ("colors", "text_intro_bg"))
 		color_bg = main_preferences_get_string ("colors", "text_intro_bg");
@@ -486,6 +504,7 @@ tutor_update_intro ()
 		color_bg = main_altcolor_get_string ("colors", "text_intro_bg");
 	}
 	gdk_rgba_parse (&color, color_bg); 
+	/* FIXME: update deprecated function for background color */
 	gtk_widget_override_background_color (get_wg ("text_tutor"), GTK_STATE_FLAG_INSENSITIVE, &color);
 	g_free (color_bg);
 
@@ -554,7 +573,6 @@ tutor_update_start ()
 
 	/*
 	 * Apply tutor background color and font to the text
-	 * FIXME: update deprecated function for background color
 	 */
 	if (main_preferences_exist ("colors", "char_untouched_bg"))
 		color_bg = main_preferences_get_string ("colors", "char_untouched_bg");
@@ -566,6 +584,7 @@ tutor_update_start ()
 		g_free (color_bg);
 		color_bg = main_altcolor_get_string ("colors", "char_untouched_bg");
 	}
+	/* FIXME: update deprecated function for background color */
 	gdk_rgba_parse (&color, color_bg);
 	gtk_widget_override_background_color (get_wg ("text_tutor"), GTK_STATE_FLAG_INSENSITIVE, &color);
 	g_free (color_bg);
@@ -583,7 +602,9 @@ tutor_update_start ()
 		start = end;
 		if (! gtk_text_iter_forward_char (&end))
 			break;
+		/* This second one seems to not be needed. FIXME ?
 		gtk_text_buffer_apply_tag_by_name (buf, "char_keep_wrap2", &start, &end);
+		*/
 		start = end;
 	}
 	
@@ -1368,10 +1389,9 @@ tutor_calc_stats ()
 	}
 	g_free (tmp_str2);
 
-	/* Is this really needed? We don't remember... FIXME (remove?)
+	/* This is needed to repaint the final comments with normal black foreground. */
 	gtk_text_buffer_get_bounds (buf, &start, &end);
 	gtk_text_buffer_apply_tag_by_name (buf, "char_keep_wrap", &start, &end);
-	*/
 
 	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (wg), gtk_text_buffer_get_insert (buf));
 }
